@@ -13,7 +13,7 @@ use Exporter qw/ import /;
 our @EXPORT    = qw( conjunction );
 our @EXPORT_OK = @EXPORT;
 
-our $VERSION = 'v2.1.3';
+our $VERSION = 'v2.1.4';
 
 # Language-specific definitions (these may not be correct, and certainly
 # they are not complete... E-mail corrections and additions to the author
@@ -127,7 +127,7 @@ Lingua::Conjunction - Convert lists into simple linguistic conjunctions
 
 =head1 VERSION
 
-version v2.1.3
+version v2.1.4
 
 =head1 SYNOPSIS
 
@@ -164,9 +164,20 @@ calling the appropriate subroutine:
     Lingua::Conjunction->lang('en');   # use 'and' (default)
     Lingua::Conjunction->lang('es');   # use 'y'
 
-Supported languages in this version are English, Spanish, French, Italian,
-German, Portuguese, Norwegian, Danish, Dutch, Afrikaans, Swahili, and Latin.
-(Klingon is intentionally not supported.)
+Supported languages in this version are
+Afrikaans,
+Danish,
+Dutch,
+English,
+French,
+German,
+Indonesian,
+Italian,
+Latin,
+Norwegian,
+Portuguese,
+Spanish,
+and Swahili.
 
 You can also set connectives individually:
 
@@ -249,7 +260,7 @@ Mohammad S Anwar <mohammad.anwar@yahoo.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2018 by Robert Rothenberg.
+This software is Copyright (c) 1999-2020 by Robert Rothenberg.
 
 This is free software, licensed under:
 
